@@ -19,7 +19,7 @@
 
 ###    Author: dxu@litespeedtech.com (David Shue)
 
-VERSION=1.0.1
+VERSION=1.0.0
 moduledir="modreqparser modinspector uploadprogress "
 OS=`uname`
 ISLINUX=no
@@ -232,11 +232,6 @@ prepareLinux()
                     cat /etc/lsb-release | grep "DISTRIB_RELEASE=18." >/dev/null
                     if [ $? = 0 ] ; then
                         OSTYPE=UBUNTU18
-                    else
-                        cat /etc/lsb-release | grep "DISTRIB_RELEASE=20." >/dev/null
-                        if [ $? = 0 ] ; then
-                            OSTYPE=UBUNTU20
-                        fi
                     fi
                 fi
             fi
@@ -270,6 +265,7 @@ prepareLinux()
         
         apt-get -y update
         apt-get -f -y install
+        apt-get -y install gcc g++
         apt-get -y install wget
         apt-get -y install curl
         apt-get -y install make
@@ -482,34 +478,6 @@ freebsdFix()
             touch ./needreboot.txt
         fi
     fi
-}
-
-
-fixPagespeed()
-{
-PSOLVERSION=1.11.33.4
-cat << EOF > ../thirdparty/psol-$PSOLVERSION/include/pagespeed/kernel/base/scoped_ptr.h
-/**
-* Due the compiling issue, this file was updated from the original file.
-*/
-#ifndef PAGESPEED_KERNEL_BASE_SCOPED_PTR_H_
-#define PAGESPEED_KERNEL_BASE_SCOPED_PTR_H_
-#include "base/memory/scoped_ptr.h"
-
-namespace net_instaweb {
-template<typename T> class scoped_array : public scoped_ptr<T[]> {
-public:
-    scoped_array() : scoped_ptr<T[]>() {}
-    explicit scoped_array(T* t) : scoped_ptr<T[]>(t) {}
-};
-}
-#endif
-
-EOF
-
-
-
-
 }
 
 cd `dirname "$0"`
@@ -535,16 +503,16 @@ mkdir thirdparty/lib64
 cd thirdparty/script/
 
 
-#Remove  unittest-cpp and add bcrypt
-sed -i -e "s/unittest-cpp/bcrypt/g" ./build_ols.sh
+ 
+sed -i -e "s/unittest-cpp/ /g" ./build_ols.sh
 
 if [ "${ISLINUX}" != "yes" ] ; then
     sed -i -e "s/psol/ /g"  ./build_ols.sh
 fi
 
-
 ./build_ols.sh
 
+
 cd ${CURDIR}
 
 updateSrcCMakelistfile
@@ -557,10 +525,6 @@ cp ../thirdparty/src/brotli/out/*.a          ../thirdparty/lib64/
 cp ../thirdparty/src//libxml2/.libs/*.a      ../thirdparty/lib64/
 cp ../thirdparty/src/libmaxminddb/include/*  ../thirdparty/include/
 
-if [ "${ISLINUX}" = "yes" ] ; then
-    fixPagespeed
-fi
-
 #special case modsecurity
 cd src/modules/modsecurity-ls
 ln -sf ../../../../thirdparty/src/ModSecurity .
