@@ -22,7 +22,6 @@
 #include "cgi/suexec.h"
 #include "registry/extappregistry.h"
 
-#include <http/httpserverconfig.h>
 #include <http/httpvhost.h>
 #include <http/serverprocessconfig.h>
 #include <log4cxx/logger.h>
@@ -452,6 +451,12 @@ int LocalWorker::workerExec(LocalWorkerConfig &config, int fd)
                         config.getName());
             return LS_FAIL;
         }
+        
+        
+        LS_INFO("[LocalWorker::workerExec] VHost:%s suExec check "
+                "uid %d gid %d setuidmode %d.",
+                pVHost->getName(), pVHost->getUid(), pVHost->getGid(),
+                pVHost->getRootContext().getSetUidMode());
     }
     //if (( uid == HttpGlobals::s_uid )&&
     //    ( gid == HttpGlobals::s_gid ))
@@ -496,50 +501,31 @@ int LocalWorker::workerExec(LocalWorkerConfig &config, int fd)
         *(argv[0] - 1) = '/';
     else
         pDir = argv[0];
-
-    int flags = 0;
-    LS_DBG("Check bwrap, cgroups, pVHost: %p\n", pVHost);
-    if ((pVHost && pVHost->enableBwrap())
-        || (!pVHost && HttpServerConfig::getInstance().getBwrap() == HttpServerConfig::BWRAP_ON))
-    {
-        flags |= LSCGID_FLAG_BWRAP;
-        LS_DBG("Enabling bwrap from %s\n", pVHost ? "VHost" : "ServerConfig");
-    }
-    else
-        LS_DBG("pVHost enableBwrap: %d, procConfig.getBwrap: %d\n",
-               pVHost && pVHost->enableBwrap(), HttpServerConfig::getInstance().getBwrap());
-
-    if ((pVHost && pVHost->enableCGroup())
-        || (!pVHost && ServerProcessConfig::getInstance().getCGroupDefault()))
-    {
-        LS_DBG("Enabling Cgroups from %s\n", pVHost ? "VHost" : "ServerConfig");
-        flags |= LSCGID_FLAG_CGROUP;
-    }
-
-    if (config.getDropCaps())
-    {
-        LS_DBG("LSCGID_FLAG_DROP_CAPS is set\n");
-        flags |= LSCGID_FLAG_DROP_CAPS;
-    }
     SUExec::getSUExec()->prepare(uid, gid, config.getPriority(),
                                  config.getUmask(),
                                  pChrootPath, chrootLen,
-                                 pDir, strlen(pDir),
-                                 argv, config.getEnv()->get(),
-                                 config.getRLimits(),
-                                 flags);
+                                 pDir, strlen(pDir), config.getRLimits());
 
     LS_NOTICE("[LocalWorker::workerExec] Config[%s]: suExec uid %d gid %d cmd %s,"
-            " final uid %d gid %d, flags: %d.",
+            " final uid %d gid %d.",
             config.getName(), config.getUid(),
             config.getGid(), config.getCommand(),
-            uid, gid, flags);
+            uid, gid);
 
     int rfd = -1;
     int pid;
-
+    //if ( config.getStartByServer() == 2 )
+    //{
     pid = SUExec::getSUExec()->cgidSuEXEC(
-              MainServerConfig::getInstance().getServerRoot(), &rfd, fd);
+              MainServerConfig::getInstance().getServerRoot(), &rfd, fd, argv,
+              config.getEnv()->get(), NULL);
+    //}
+    //else
+    //{
+    //    pid = HttpGlobals::s_pSUExec->suEXEC(
+    //        HttpGlobals::s_pServerRoot, &rfd, fd, argv,
+    //        config.getEnv()->get(), NULL );
+    //}
 
     if (pid == -1)
     {
@@ -1055,7 +1041,9 @@ TRY_AGAIN:
     }
 
     removeOldDetachedSocket();
-    ret = CoreSocket::listen(service_addr, config.getBackLog(), &fd, -1, -1);
+    
+    ret = CoreSocket::listen(service_addr, config.getBackLog(), &fd,
+                             LS_SOCK_NODELAY, -1, -1);
     if (fd == -1)
     {
         LS_ERROR("[%s]: Failed to listen socket [%s]: %s",
