@@ -28,7 +28,6 @@
 #include <log4cxx/logrotate.h>
 #include <quic/quicengine.h>
 
-#include <util/gpath.h>
 #include <new>
 
 #include <stdio.h>
@@ -55,13 +54,6 @@ void HttpLog::parse_error(const char *pCurLine, const char *pError)
 }
 
 
-void HttpLog::parse_warn(const char *pCurLine, const char *pError)
-{
-    LS_WARN(s_pCurLogger, "[%s] rewrite: %s while parsing: %s",
-             s_pLogId, pError, pCurLine);
-}
-
-
 void HttpLog::setCurLogger(LOG4CXX_NS::Logger *pLogger, const char *pId)
 {
     s_pCurLogger = pLogger;
@@ -109,12 +101,6 @@ void HttpLog::init()
 }
 
 
-void HttpLog::updateLogPatternWithPid(int pid)
-{
-    lsnprintf( s_logPattern, sizeof(s_logPattern), "%%d [%%p] [%d] %%m", pid);
-}
-
-
 bool HttpLog::isEnabled(Logger *pLogger, int level)
 {
     if (pLogger)
@@ -156,12 +142,6 @@ void HttpLog::toggleDebugLog()
 }
 
 
-int  HttpLog::getLogLevel()
-{
-    return logger()->getLevel();
-}
-
-
 void HttpLog::setLogLevel(int level)
 {
     logger()->setLevel(level);
@@ -192,7 +172,8 @@ LOG4CXX_NS::Logger *HttpLog::getErrorLogger()
     return logger();
 }
 
-#define MAX_PATH_LEN                8192
+
+#define MAX_LOG_LINE_LEN 4096
 int HttpLog::logAccess(const char *pVHost, int len, HttpSession *pSession)
 {
     accessLog()->log(pVHost, len, pSession);
@@ -200,23 +181,12 @@ int HttpLog::logAccess(const char *pVHost, int len, HttpSession *pSession)
 }
 
 
-int HttpLog::checkLogPathValid(const char *org)
+int HttpLog::checkLogPathValid(const char *pFileName)
 {
     const char *excludeFileList[] = { ".cgi", ".pl", ".shtml" };
     const char *excludeDirList[] = { "admin/conf", "admin/html", "conf" };
-    char real[MAX_PATH_LEN+1];
-    const char *pFileName = real;
-    char *end = lstrncpy(real, org, MAX_PATH_LEN);
-    int len = end - real;
-    int ret = GPath::checkSymLinks(real, end, real + MAX_PATH_LEN, real, 1);
-    if (ret == -1)
-        pFileName = org;
-    else
-        len = ret;
-    if (len < 5)
-        return 0;
-
     int i;
+    int len = strlen(pFileName);
     for (i=0; i<sizeof(excludeFileList)/ sizeof(char *); ++i)
     {
         int ll = strlen(excludeFileList[i]);
@@ -228,23 +198,6 @@ int HttpLog::checkLogPathValid(const char *org)
         }
     }
 
-    //For special ".ph???"
-    const char *pExt = strrchr(pFileName, '.');
-    if (pExt && strlen(pExt) >= 3 && strncasecmp(pExt, ".ph", 3) == 0)
-    {
-        HttpLog::perror("Cannot use the suffix as log file", pFileName);
-        return LS_FAIL;
-    }
-
-
-    if (strncmp(pFileName, "/etc/", 5) == 0)
-    {
-        if (strncasecmp(pFileName + 5, "apache", 6) == 0
-            || strncasecmp(pFileName + 5, "httpd", 5) == 0)
-            return LS_FAIL;
-        return 0;
-    }
-
     if (len > s_serverRoot.len() + 4 &&
         strncmp(pFileName, s_serverRoot.c_str(), s_serverRoot.len()) == 0)
     {
@@ -261,6 +214,13 @@ int HttpLog::checkLogPathValid(const char *org)
         }
     }
 
+    //For special ".php???"
+    const char *pExt = strrchr(pFileName, '.');
+    if (pExt && strlen(pExt) >= 4 && strncasecmp(pExt, ".php", 4) == 0)
+    {
+        HttpLog::perror("Cannot use the suffix as log file", pFileName);
+        return LS_FAIL;
+    }
     return 0;
 }
 
