@@ -63,22 +63,10 @@ SubstItem::~SubstItem()
 {
     if (m_value.m_pStr)
     {
-        switch (m_type)
-        {
-        case REF_STRING:
-        case REF_ENV:
-        case REF_HTTP_HEADER:
-        case REF_SSI_VAR:
-        case REF_RESP_HEADER:
+        if ((m_type == REF_STRING) || (m_type == REF_ENV))
             delete m_value.m_pStr;
-            break;
-        case REF_FORMAT_STR:
+        if (m_type == REF_FORMAT_STR)
             delete(SubstFormat *)m_value.m_pAny;
-            break;
-        case REF_EXPR:
-            delete(Expression *)m_value.m_pAny;
-            break;
-        }
     }
 }
 
@@ -94,8 +82,6 @@ SubstItem::SubstItem(const SubstItem &rhs)
         {
         case REF_STRING:
         case REF_ENV:
-        case REF_SSI_VAR:
-        case REF_RESP_HEADER:
             m_value.m_pStr = new AutoStr2(*rhs.m_value.m_pStr);
             break;
         case REF_FORMAT_STR:
@@ -802,10 +788,10 @@ int RequestVars::getReqVar(HttpSession *pSession, int type, char *&pValue,
 
     case REF_BYTES_TOTAL:
         i = StringTool::offsetToStr(pValue, bufLen,
-                                    pSession->getBytesRecv() +
+                                    pSession->getBytesRecv() + 
                                     pSession->getBytesSent());
         return i;
-
+        
     case REF_HTTPS:
         i = snprintf(pValue, bufLen, "%s", pSession->isHttps() ? "on" : "off");
         return i;
@@ -954,7 +940,7 @@ int RequestVars::getReqVar2(HttpSession *pSession, int type, char *&pValue,
         HioCrypto *pCrypto = pSession->getCrypto();
         if (!pCrypto)
             return 0;
-
+        
         return pCrypto->getEnv((HioCrypto::ENV)(HioCrypto::CRYPTO_VERSION +
                                 (type - LSI_VAR_SSL_VERSION)), pValue, bufLen);
     }
@@ -1153,8 +1139,8 @@ static const char *const s_pHeaders[] =
     "if-modified-since",
     "if-match",
     "if-none-match",
-    "if-range",
     "if-unmodified-since",
+    "if-range",
     "keep-alive",
     "range",
     "x-forwarded-for",
@@ -1345,12 +1331,12 @@ int RequestVars::setEnv(HttpSession *pSession, const char *pName,
             pSession->getReq()->keepAlive(false);
             return 0;
         }
-        else if (strcasecmp(pName, "noconntimeout") == 0)
-        {
-            LS_DBG_M(pSession->getLogSession(),
-                    "turn off connection timeout.");
-            pSession->setFlag(HSF_NO_CONN_TIMEOUT);
-        }
+        //else if ( strcasecmp( pName, "noconntimeout" ) == 0 )
+        //{
+        //    LS_DBG_M(pSession->getLogSession(),
+        //            "turn off connection timeout.");
+        //    pSession->setFlag( HSF_NO_CONN_TIMEOUT );
+        //}
         else if (strcasecmp(pName, "no-gzip") == 0)
         {
             if (strncmp(pValue, "0", 1) != 0)
