@@ -1,6 +1,6 @@
 /*****************************************************************************
 *    Open LiteSpeed is an open source HTTP server.                           *
-*    Copyright (C) 2013 - 2018  LiteSpeed Technologies, Inc.                 *
+*    Copyright (C) 2013 - 2020  LiteSpeed Technologies, Inc.                 *
 *                                                                            *
 *    This program is free software: you can redistribute it and/or modify    *
 *    it under the terms of the GNU General Public License as published by    *
@@ -96,7 +96,7 @@ typedef struct lsi_module_internal_s
 class LsiSession : public evtcbtail_s
 {
 public:
-    LsiSession() {};
+    LsiSession() { m_pModuleConfig = NULL; };
     virtual ~LsiSession() {};
     ModuleConfig *getModuleConfig()    { return m_pModuleConfig; };
     virtual LogSession *getLogSession() = 0;
