@@ -51,7 +51,6 @@
 #include <util/vmembuf.h>
 #include <util/httpfetch.h>
 #include <socket/gsockaddr.h>
-#include <edio/evtcbque.h>
 
 #include <sys/sysctl.h>
 
@@ -83,7 +82,7 @@
 /***
  * Do not change the below format, it will be set correctly while packing the code
  */
-#define BUILDTIME  " (built: Sun Feb 14 15:51:55 UTC 2021)"
+#define BUILDTIME  " (built: Thu Apr 16 19:59:00 UTC 2020)"
 
 #define GlobalServerSessionHooks (LsiApiHooks::getServerSessionHooks())
 
@@ -959,14 +958,13 @@ int LshttpdMain::init(int argc, char *argv[])
 #endif
     }
 
-    m_pid = getpid();
-
     if (!m_iConfTestMode)
     {
         enableCoreDump();
 
         if (testRunningServer() != 0)
             return 2;
+        m_pid = getpid();
         if (m_pidFile.writePid(m_pid))
             return 2;
 
@@ -974,9 +972,7 @@ int LshttpdMain::init(int argc, char *argv[])
             startAdminSocket();
     }
 
-    HttpLog::updateLogPatternWithPid(m_pid);
-
-    QuicEngine::setpid(m_pid);
+    QuicEngine::setpid(getpid());
 
 #ifndef IS_LSCPD
     ret = config();
@@ -1039,8 +1035,10 @@ int LshttpdMain::init(int argc, char *argv[])
         allocatePidTracker();
         m_pServer->initAdns();
         m_pServer->enableAioLogging();
-        EvtcbQue::getInstance().initNotifier();
+        m_pServer->startServing();
         cleanEnvVars();
+        
+        
         WorkCrew * pGWC = ModuleHandler::getGlobalWorkCrew();
         pGWC->startProcessing();
         if ((HttpServerConfig::getInstance().getUseSendfile() == 2)
@@ -1240,9 +1238,6 @@ void LshttpdMain::onNewChildStart(ChildProc * pProc)
     monstartup ((u_long) &__executable_start, (u_long) &__etext);
 #endif
 
-    pProc->m_pid = getpid();
-    HttpLog::updateLogPatternWithPid(pProc->m_pid);
-
     int cpu_count = HttpServerConfig::getInstance().getCpuAffinity();
     if (cpu_count > 0)
     {
@@ -1257,11 +1252,11 @@ void LshttpdMain::onNewChildStart(ChildProc * pProc)
     m_pServer->setProcNo(pProc->m_iProcNo);
     //setAffinity( 0, pProc->m_iProcNo);  //TEST: need uncomment and debug
     releaseExcept(pProc);
+    LsShmPool::setPid(pProc->m_pid);
     StdErrLogger::getInstance().movePipeFdToStdErr();
-
-    m_pServer->reinitMultiplexer();
+    m_pServer->startServing();
+    //setIntercommFds(pProc->m_iProcNo);
     m_pServer->enableAioLogging();
-    EvtcbQue::getInstance().initNotifier();
     if ((HttpServerConfig::getInstance().getUseSendfile() == 2)
         && (m_pServer->initAioSendFile() != 0))
     {
@@ -1281,8 +1276,6 @@ void LshttpdMain::onNewChildStart(ChildProc * pProc)
 
     LsShmPool::setPid(pProc->m_pid);
     QuicEngine::setpid(pProc->m_pid);
-
-    m_pool.recycle(pProc);
 }
 
 int LshttpdMain::startChild(ChildProc *pProc)
@@ -1306,6 +1299,7 @@ int LshttpdMain::startChild(ChildProc *pProc)
     if (pProc->m_pid == 0)
     {
         //child process
+        pProc->m_pid = getpid();
         onNewChildStart(pProc);
         return 0;
     }
@@ -1529,17 +1523,10 @@ void LshttpdMain::gracefulRestart()
     m_pidFile.closePidFile();
     unlink(getPidFile());
     m_pidFile.writePidFile(GRACEFUL_PID_FILE, m_pid);
-
+    m_pServer->passListeners();
     int pid = fork();
     if (!pid)
     {
-        pid = getpid();
-        LS_NOTICE( "Forked [%d] for graceful restart.", pid);
-
-        LS_NOTICE( "Start passing listener sockets through forked child [%d].", pid);
-        HttpLog::updateLogPatternWithPid(pid);
-        m_pServer->passListeners();
-
         char achCmd[1024];
         int fd = StdErrLogger::getInstance().getStdErr();
         if (fd != 2)
@@ -1607,11 +1594,14 @@ int LshttpdMain::guardCrash()
     pfds[2].events = POLLIN;
 
     s_iRunning = 1;
-
+    
     LS_NOTICE("Instance is ready for service.");
     m_pServer->restartMark(2);
-
+    
+    m_pServer->adjustListeners(iNumChildren);
+    
     startTimer();
+    
     while (s_iRunning > 0)
     {
         if (DateTime::s_curTime - lLastForkTime > 60)
@@ -1681,7 +1671,7 @@ int LshttpdMain::guardCrash()
     if (GlobalServerSessionHooks->isEnabled(LSI_HKPT_MAIN_ATEXIT))
         GlobalServerSessionHooks->runCallbackNoParam(LSI_HKPT_MAIN_ATEXIT, NULL);
 
-    LS_NOTICE("Server Stopped!\n");
+    LS_NOTICE("[PID:%d] Server Stopped!\n", getpid());
     exit(ret);
 }
 
@@ -1983,7 +1973,7 @@ int LshttpdMain::processChildCmd()
     if (n > 0)
     {
         achBuf[n] = 0;
-        LS_NOTICE("Cmd from child: [%.*s]", n, achBuf);
+        LS_NOTICE("[%d] Cmd from child: [%.*s]", m_pid, n, achBuf);
 
         char *colon = (char *)memchr(achBuf, ':', n);
         if (!colon)
