@@ -84,8 +84,6 @@ plainconfKeywords plainconf::sKeywords[] =
     {"binding",                                  NULL},
     {"botwhitelist",                             NULL},
     {"brstaticcompresslevel",                    NULL},
-    {"bubblewrap",                               NULL},
-    {"bubblewrapcmd",                            NULL},
     {"byteslog",                                 NULL},
     {"cacertfile",                               NULL},
     {"cacertpath",                               NULL},
@@ -435,6 +433,10 @@ plainconfKeywords plainconf::sKeywords[] =
     {"quicidletimeout", NULL},
     {"quicpush", NULL},
     {"quiccongestionctrl", NULL},
+    {"quicloglevel", NULL},
+
+    {"reuseport",      NULL},
+
 };
 
 static HashStringMap<plainconfKeywords *> allKeyword(29, GHash::hfCiString,
@@ -460,7 +462,7 @@ StrStrHashMap plainconf::m_confFileHash;
  */
 void plainconf::logToMem(char errorLevel, const char *format, ...)
 {
-#define MAX_LOG_LINE_LENGTH     4096
+#define MAX_LOG_LINE_LENGTH     1024
     char buf[MAX_LOG_LINE_LENGTH];
     sprintf(buf, "%c[PlainConf] ", errorLevel);
     int len = strlen(buf);
@@ -681,7 +683,6 @@ void plainconf::saveUnknownItems(const char *fileName, int lineNumber,
     if (strcasecmp(pCurNode->getName(), "module") != 0
         && strstr(name, "::") == NULL
         && strcasecmp(pCurNode->getName(), "rewrite") != 0
-        && strcasecmp(pCurNode->getName(), "context") != 0
         && strcasecmp(pCurNode->getName(), "urlFilter") != 0)
     {
         logToMem(LOG_LEVEL_ERR, "Not support [%s %s] in file %s:%d", name, value,
@@ -785,8 +786,6 @@ void plainconf::handleSpecialCase(XmlNode *pNode)
 
         if (strcasecmp(pNode->getName(), "module") == 0)
             appendValueToKey(pNode, "param", value);
-        if (strcasecmp(pNode->getName(), "context") == 0)
-            appendValueToKey(pNode, "param", value);
         else if (strcasecmp(pNode->getName(), "rewrite") == 0)
             appendValueToKey(pNode, "rules", value);
         else if (strcasecmp(pNode->getName(), "urlFilter") == 0)
@@ -1435,7 +1434,6 @@ void plainconf::loadConfFile(const char *path)
             checkInFile(path);
     }
 
-    logToMem(LOG_LEVEL_INFO, "Finished parsing file %s", path);
 }
 
 
