@@ -20,6 +20,7 @@
 #include <string.h>
 
 CacheHash::CacheHash()
+    : m_key(0)
 {
 }
 
@@ -35,7 +36,7 @@ void CacheHash::update(XXH64_state_t *pState, const char *pBuf, int len)
 
 hash_key_t CacheHash::to_ghash_key(const void *__s)
 {
-    hash_key_t __h = *((uint64_t *)__s);
+    register hash_key_t __h = *((uint64_t *)__s);
 
     return __h;
 }
