@@ -176,10 +176,7 @@ CacheEntry *DirHashCacheStore::getCacheEntry(CacheHash &hash,
 
                 //updated by another process, do not remove current object on disk
                 erase(iter);
-                if (pEntry->getRef() > 0)
-                    addToDirtyList(pEntry, "getCacheEntry, modified");
-                else
-                    delete pEntry;
+                addToDirtyList(pEntry);
                 pEntry = NULL;
                 iter = end();
             }
@@ -541,7 +538,7 @@ void DirHashCacheStore::cancelEntryInMem(CacheEntry* pEntry)
     }
     if (pEntry->getRef() > 0)
     {
-        addToDirtyList(pEntry, "cancelEntryInMem");
+        addToDirtyList(pEntry);
     }
     else
         delete pEntry;
@@ -690,16 +687,12 @@ int DirHashCacheStore::updateEntryExpire(CacheEntry* pEntry)
     
     pEntry->getHeader().m_tmExpire += DateTime::s_curTime -
                                       pEntry->getHeader().m_tmCreated;
-    off_t curOffset = lseek(fd, 0, SEEK_CUR);
-
     if (nio_lseek(fd, pEntry->getStartOffset() + CACHE_ENTRY_MAGIC_LEN,
                   SEEK_SET) == -1)
         return -1;
     if (nio_write(fd, &pEntry->getHeader(), sizeof(CeHeader)) <
         (int)sizeof(CeHeader))
         return -1;
-
-    lseek(fd, curOffset, SEEK_SET);
     return 0;
 }
 
